@@ -6,7 +6,6 @@ import shutil
 import subprocess
 import tempfile
 from dataclasses import dataclass, field
-from distutils.spawn import find_executable
 from pathlib import Path
 from typing import List, Optional
 
@@ -20,7 +19,7 @@ from PIL import Image
 # Note trimesh has not updated their code to work with v4.0 which is why we do not use
 # their `convex_decomposition` function.
 # TODO(kevin): Is there a way to assert that the V-HACD version is 4.0?
-_VHACD_EXECUTABLE = find_executable("testVHACD", path=os.environ["PATH"])
+_VHACD_EXECUTABLE = shutil.which("TestVHACD")
 
 # Names of the V-HACD output files.
 _VHACD_OUTPUTS = ["decomp.obj", "decomp.stl"]
@@ -231,14 +230,14 @@ def process_obj(filename: Path, args: Args) -> None:
     if isinstance(mesh, trimesh.base.Trimesh):
         # No submeshes, just save the mesh.
         savename = str(work_dir / f"{filename.stem}.obj")
+        logging.info(f"\tSaving mesh {savename}")
         mesh.export(savename, include_texture=True, header=None)
-        return
-
-    logging.info("Grouping and saving submeshes by material...")
-    for i, geom in enumerate(mesh.geometry.values()):
-        savename = str(work_dir / f"{filename.stem}_{i}.obj")
-        logging.info(f"\tSaving submesh {savename}")
-        geom.export(savename, include_texture=True, header=None)
+    else:
+        logging.info("Grouping and saving submeshes by material...")
+        for i, geom in enumerate(mesh.geometry.values()):
+            savename = str(work_dir / f"{filename.stem}_{i}.obj")
+            logging.info(f"\tSaving submesh {savename}")
+            geom.export(savename, include_texture=True, header=None)
 
     # Delete any MTL files that were created during trimesh processing, if any.
     for file in [
@@ -309,8 +308,11 @@ def process_obj(filename: Path, args: Args) -> None:
             obj_body.add(
                 "geom",
                 type="mesh",
-                file=str(work_dir / f"{filename.stem}.obj"),
-                material=filename.stem,
+                mesh=str(meshname.stem),
+                material=material.name,
+                contype="0",
+                conaffinity="0",
+                group="2",
             )
         else:
             for i, (name, geom) in enumerate(mesh.geometry.items()):
